// VoiceActivityListener.aidl
package com.shuqi.y4.voice.aidl;

import com.shuqi.y4.voice.bean.VoiceProgressBean;
import com.shuqi.y4.voice.bean.VoicePageContentData;

/**
 * VoiceService与启动Service的ReadActivity间的回调
 * @author Jianda.Yang
 * @date 2016/2/17
 */
interface IVoiceCallbackListener {
    /**
        * 听书启动当前页内容
        */
       void onVoicePlayCurrentPage(in VoicePageContentData pageContentData);

       /**
        * 绘制指定的矩形
        */
       void drawSelectedVoiceArea(in VoiceProgressBean voiceProgressBean);

       /**
        * 加载下一页
        */
       void loadNextPage();

       /**
        * 加载下一章
        */
       void loadNextChapter();

       /**
        * 加载上一章
        */
       void loadPrvChapter();

       /**
        * 需要下载听说插件
        */
       void downloadVoicePlug();

       /**
        * 关闭阅读页听书模式
        */
       void closeVoiceMode();

       /**
        * 听书播放下一章 检查是否有下一章
        */
       void onVoicePlayNextChapter();

       /**
        * 听书播放上一章 检查是否有上一章
        */
       void onVoicePlayPreChapter();

       /**
        * 听书SDK获取发音人数据异常
        */
       void onVoiceSpeechError();

       /**
        * 听书SDK未能处理的异常
        */
       void onVoiceUnHandleError();

       /**
        * 通知阅读页关闭确认关闭语音弹窗
        */
       void dismissVoiceCloseDialog();

       /**
        * 听书插件被卸载
        */
       void onVoicePlugUninstall();

       /**
        * 通知阅读页控制view更新播放按钮状态
        */
       void onVoiceRefreshPlayButtonState();

        /**
         * 更新听书音频进度信息
         */
       void initVoiceProgressInfo(in VoiceProgressBean voiceProgressBean, boolean autoStart);

        /**
         * 定时关闭回调
         */
       boolean onTimeRun(int remainTime, int totalTime);

        /**
        * 音频开始播放
        * @param autoPlay 是否已自动播放
        */
       void onAudioStart(boolean autoPlay);

        /**
        * 音频停止播放
        * @param preparing 是否loading下一音频
        */
       void onAudioStop(boolean preparing);

        /**
        * 关闭服务
        */
       void onServiceStop(boolean stopFloatView);

       /**
        * 通知栏打开阅读页
        */
       void openReadActivity();

        /**
        * 网络切换
        */
       void showNetWorkConfirmDialog();

        /**
        * 当前地址无效
        */
       void onUrlNotArrived();

       /**
       * 当前地址无效
       */
       void onLocalFilePlayError();
        /**
       * seek开始回调
       */
       void onSeekLoadingStart();
       /**
       * seek完成回调
       */
       void onSeekLoadingComplete();
       /**
       * 播放状态每分钟回调
       */
       void onMinuteClock();

       /**
        * 是否章节加载失败
        */
       boolean isChapterLoadError();

        /**
        * 初始化完成
        */
       void onInitFinished(long time);

        /**
        * 初始化完成
        */
       void onPlayEnd(long time);

       /**
        * 播放状态回调到主进程-播放开始
        */
       void onVoicePlayStart();

       /**
        * 播放状态回调到主进程-播放暂停
        */
       void onVoicePlayPause();

       /**
        * 播放状态回调到主进程-播放恢复
        */
       void onVoicePlayResume();

       /**
        * 播放状态回调到主进程-播放关闭
        */
       void onVoicePlayClose(String bookId);

       void onSampleComplete();
}
